==> oeshop_0.01.tar.gz: oeshop/admin/lib/prize_lib.php <==
<?php
/*
OEShop 

:  - ȣ
: E-Mail - compile@dreamwiz.com
: Home - http://www.oe2k.com
:     - з 
:
:  α׷ GNU/GPL  ,  뵵ε    Ǹ   ʽϴ.
: , θ , н,   α׷  񿵸  ο  մϴ.
*/

// з(category) Ʈ Class
class read_category {
	var $result_cat;
	var $total;

	// зƮ б
	// $category_code =  зڵ
	// $db_conn = DB 
	function read_category($category_code, $depth, $db_conn) {
		if (empty($category_code) || $category_code == 0) {
			$query = "SELECT category_code, category_name, category_depth FROM shop_category WHERE category_depth='1' ORDER BY category_code";
		}
		else {
			$next_depth = $depth + 1;
			$query = "SELECT category_code, category_name, category_depth FROM shop_category WHERE category_code LIKE '$category_code%' and category_depth <= $next_depth ORDER BY category_code";
		}

		$result = @mysql_query($query, $db_conn);
		if (!$result) {
			echo "DB  Ȥ   ֽϴ.<hr size='1'>";
			echo mysql_error();
			exit;
		}
		else {
			$this->result_cat = $result;
			$this->total = mysql_num_rows($result);
		}
	}

	// зƮ 
	function get_category() {
		$row = mysql_fetch_assoc($this->result_cat);
		return $row;
	}
}

// ǰƮ  Class
class read_prize {
	var $category_code;
	var $result_prize;
	var $total;
	var $total_data;
	var $page;
	var $scale;
	var $limit_scale;

	// ǰƮ б
	// $category_code =  зڵ
	// $db_conn = DB 
	// $page =   ȣ
	// $limit_scale =     
	function read_prize($category_code, $search_item, $search_val, $page, $scale, $limit_scale, $db_conn) {
		if (empty($page)) {
			$start = 0;
		}
		else {
			$start = $page * $limit_scale;
		}

		$query = "SELECT id, pos, prize_num, prize_sail2, prize_amount, prize_view, prize_name, view_img FROM shop_prize WHERE ";
		$query .= "category_code like '$category_code%' ORDER BY pos ";
		$query .= "LIMIT $start, $limit_scale";
		$this->result_prize = mysql_query($query, $db_conn);
		$this->total = mysql_num_rows($this->result_prize);

		$query = "SELECT COUNT(*) AS total FROM shop_prize WHERE ";
		$query .= "category_code like '$category_code%'";
		$result_total = mysql_query($query, $db_conn);
		$t_row = mysql_fetch_assoc($result_total);
		$this->total_data = $t_row[total];

		$this->category_code = $category_code;
		$this->search_item = $search_item;
		$this->search_val = $search_val;
		$this->page = $page;
		$this->scale = $scale;
		$this->limit_scale = $limit_scale;
	}

	// ǰƮ 
	function get_prize() {
		return mysql_fetch_assoc($this->result_prize);
	}

	// ǰƮ ¡
	function get_paging() {
		$limit_page = 10;
		if (empty($this->scale)) { $this->scale = 0; }

		$total_page = (int)($this->total_data / $this->limit_scale);
		$temp_scale = (int)($total_page / $limit_page);
		$total_scale = $temp_scale;
		$temp_data = $temp_scale * $limit_page * $this->limit_scale;

		if ($this->scale == $total_scale) {
			if ($this->total_data >= $temp_data) {
				$tale = $this->total_data - $temp_data;
				$tale_num = $tale / $this->limit_scale;

				if ($tale_num > (int)$tale_num) {
					$total_page = (int)$tale_num + 1;
				}
				else {
					$total_page = (int)$tale_num;
				}
			}
		}
		else {
			$total_page = $limit_page;
		}

		// ¡ ũ
		$default_lnk = "prize_list.php?category_code=".$this->category_code."&search_item=".$this->search_item."&search_val=".$this->search_val;

		// ó
		if ($this->scale == 0) {
			$ret_val[] = "#";
		}
		else {
			$ret_val[] = $default_lnk."&page=0&scale=0";
		}

		//  
		$temp_scale = ($this->scale - 1);
		$temp_page = $temp_scale * $limit_page;
		if ($temp_scale < 0) {
			$ret_val[] = "#";
		}
		else {
			$ret_val[] = $default_lnk."&page=".$temp_page."&scale=".$temp_scale;
		}

		//  ¡...
		for ($i = 0; $i < $limit_page; $i++) {
			$temp = ($this->scale * $limit_page) + $i;

			if ($temp == $this->page) {
				$ret_val[] = "#";
			}
			else {
				$ret_val[] = $default_lnk."&page=".$temp."&scale=".$this->scale;
			}
		}

		// ,  
		if ($this->scale < $total_scale) {
			$next_scale = $this->scale + 1;
			$next_page = $next_scale * $limit_page;
			$end_page = $total_scale * $limit_page;
			$ret_val[] = $default_lnk."&page=".$next_page."&scale=".$next_scale;
			$ret_val[] = $default_lnk."&page=".$end_page."&scale=".$total_scale;
		}
		else {
			$ret_val[] = "#";
			$ret_val[] = "#";
		}

		return $ret_val;
	}
}

// ǰ  б
function read_prize($id, $db_conn) {
	$query = "SELECT * FROM shop_prize WHERE id='$id'";
	$result = mysql_query($query, $db_conn);
	return mysql_fetch_assoc($result);	
}

// 
function error_msg($err_msg) {
	echo ("
	");
}
?>

==> oeshop_0.03.tar.gz: oeshop/admin/lib/prize_lib.php <==
<?php
/*
OEShop 

:  - ȣ
: E-Mail - compile@dreamwiz.com
: Home - http://www.oe2k.com
:     - з 
:
:  α׷ GNU/GPL  ,  뵵ε    Ǹ   ʽϴ.
: , θ , н,   α׷  񿵸  ο  մϴ.
*/

// з(category) Ʈ Class
class read_category {
	var $result_cat;
	var $total;

	// зƮ б
	// $category_code =  зڵ
	// $db_conn = DB 
	function read_category($category_code, $depth, $db_conn) {
		if (empty($category_code) || $category_code == 0) {
			$query = "SELECT category_code, category_name, category_depth FROM shop_category WHERE category_depth='1' ORDER BY category_code";
		}
		else {
			$next_depth = $depth + 1;
			$query = "SELECT category_code, category_name, category_depth FROM shop_category WHERE category_code LIKE '$category_code%' and category_depth <= $next_depth ORDER BY category_code";
		}

		$result = @mysql_query($query, $db_conn);
		if (!$result) {
			echo "DB  Ȥ   ֽϴ.<hr size='1'>";
			echo mysql_error();
			exit;
		}
		else {
			$this->result_cat = $result;
			$this->total = mysql_num_rows($result);
		}
	}

	// зƮ 
	function get_category() {
		$row = mysql_fetch_assoc($this->result_cat);
		return $row;
	}
}

// ǰƮ  Class
class read_prize {
	var $category_code;
	var $result_prize;
	var $total;
	var $total_data;
	var $page;
	var $scale;
	var $limit_scale;

	// ǰƮ б
	// $category_code =  зڵ
	// $db_conn = DB 
	// $page =   ȣ
	// $limit_scale =     
	function read_prize($category_code, $search_item, $search_val, $page, $scale, $limit_scale, $db_conn) {
		if (empty($page)) {
			$start = 0;
		}
		else {
			$start = $page * $limit_scale;
		}

		$query = "SELECT id, pos, prize_num, prize_sail2, prize_amount, prize_view, prize_name, view_img FROM shop_prize WHERE ";
		$query .= "category_code like '$category_code%' ORDER BY pos ";
		$query .= "LIMIT $start, $limit_scale";
		$this->result_prize = mysql_query($query, $db_conn);
		$this->total = mysql_num_rows($this->result_prize);

		$query = "SELECT COUNT(*) AS total FROM shop_prize WHERE ";
		$query .= "category_code like '$category_code%'";
		$result_total = mysql_query($query, $db_conn);
		$t_row = mysql_fetch_assoc($result_total);
		$this->total_data = $t_row[total];

		$this->category_code = $category_code;
		$this->search_item = $search_item;
		$this->search_val = $search_val;
		$this->page = $page;
		$this->scale = $scale;
		$this->limit_scale = $limit_scale;
	}

	// ǰƮ 
	function get_prize() {
		return mysql_fetch_assoc($this->result_prize);
	}

	// ǰƮ ¡
	function get_paging() {
		$limit_page = 10;
		if (empty($this->scale)) { $this->scale = 0; }

		$total_page = (int)($this->total_data / $this->limit_scale);
		$temp_scale = (int)($total_page / $limit_page);
		$total_scale = $temp_scale;
		$temp_data = $temp_scale * $limit_page * $this->limit_scale;

		if ($this->scale == $total_scale) {
			if ($this->total_data >= $temp_data) {
				$tale = $this->total_data - $temp_data;
				$tale_num = $tale / $this->limit_scale;

				if ($tale_num > (int)$tale_num) {
					$total_page = (int)$tale_num + 1;
				}
				else {
					$total_page = (int)$tale_num;
				}
			}
		}
		else {
			$total_page = $limit_page;
		}

		// ¡ ũ
		$default_lnk = "prize_list.php?category_code=".$this->category_code."&search_item=".$this->search_item."&search_val=".$this->search_val;

		// ó
		if ($this->scale == 0) {
			$ret_val[] = "#";
		}
		else {
			$ret_val[] = $default_lnk."&page=0&scale=0";
		}

		//  
		$temp_scale = ($this->scale - 1);
		$temp_page = $temp_scale * $limit_page;
		if ($temp_scale < 0) {
			$ret_val[] = "#";
		}
		else {
			$ret_val[] = $default_lnk."&page=".$temp_page."&scale=".$temp_scale;
		}

		//  ¡...
		if ($total_page > $limit_page) {
			$for_val = 10;
		}
		else {
			$for_val = $total_page;
		}

		for ($i = 0; $i < $for_val; $i++) {
			$temp = ($this->scale * $limit_page) + $i;

			if ($temp == $this->page) {
				$ret_val[] = "#";
			}
			else {
				$ret_val[] = $default_lnk."&page=".$temp."&scale=".$this->scale;
			}
		}

		// ,  
		if ($this->scale < $total_scale) {
			$next_scale = $this->scale + 1;
			$next_page = $next_scale * $limit_page;
			$end_page = $total_scale * $limit_page;
			$ret_val[] = $default_lnk."&page=".$next_page."&scale=".$next_scale;
			$ret_val[] = $default_lnk."&page=".$end_page."&scale=".$total_scale;
		}
		else {
			$ret_val[] = "#";
			$ret_val[] = "#";
		}

		return $ret_val;
	}
}

// ǰ  б
function read_prize($id, $db_conn) {
	$query = "SELECT * FROM shop_prize WHERE id='$id'";
	$result = mysql_query($query, $db_conn);
	return mysql_fetch_assoc($result);	
}

// 
function err_msg($err_msg) {
	echo ("$err_msg
	");
}

// з ִ ˻
function chk_sub_category($category_code, $db_conn) {
	$query = "SELECT COUNT(*) AS total FROM shop_category WHERE category_code like '$category_code-%'";
	$result = mysql_query($query, $db_conn);
	$row = mysql_fetch_assoc($result);

	if ($row[total] > 0) {
		return true;
	}
	else {
		return false;
	}
}
?>
